--
-- Base de données : `base_simple`
--

CREATE DATABASE IF NOT EXISTS `base_simple` DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;
USE `base_simple`;

-- --------------------------------------------------------

--
-- Structure de la table `categorie`
--

DROP TABLE IF EXISTS `categorie`;
CREATE TABLE IF NOT EXISTS `categorie` (
  `pk_cat` int(11) NOT NULL AUTO_INCREMENT,
  `libelle` varchar(255) NOT NULL,
  PRIMARY KEY (`pk_cat`),
  KEY `pk_cat` (`pk_cat`)
) ENGINE=InnoDB AUTO_INCREMENT=5 DEFAULT CHARSET=utf8;

--
-- Déchargement des données de la table `categorie`
--

INSERT INTO `categorie` (`pk_cat`, `libelle`) VALUES
(1, 'CAT_1'),
(2, 'CAT_2'),
(3, 'CAT_3'),
(4, 'CAT_4');

-- --------------------------------------------------------

--
-- Structure de la table `client`
--

DROP TABLE IF EXISTS `client`;
CREATE TABLE IF NOT EXISTS `client` (
  `pk_client` int(11) NOT NULL AUTO_INCREMENT,
  `nom` varchar(255) NOT NULL,
  `email` varchar(256) DEFAULT NULL,
  `dept` int(3) NOT NULL,
  `latitude` double(24,8) DEFAULT NULL,
  `longitude` double(24,8) DEFAULT NULL,
  PRIMARY KEY (`pk_client`)
) ENGINE=InnoDB AUTO_INCREMENT=3 DEFAULT CHARSET=utf8;

--
-- Déchargement des données de la table `client`
--

INSERT INTO `client` (`pk_client`, `nom`, `email`, `dept`, `latitude`, `longitude`) VALUES
(1, 'Client 1', 'email@client1.com', 69, 45.76695695, 4.83288933),
(2, 'Client 2', NULL, 33, 45.76526928, 4.83411115);

-- --------------------------------------------------------

--
-- Structure de la table `commande_web`
--

DROP TABLE IF EXISTS `commande_web`;
CREATE TABLE IF NOT EXISTS `commande_web` (
  `pk_commande` int(11) NOT NULL,
  `ref` varchar(11) CHARACTER SET latin1 NOT NULL,
  `fk_client` int(11) NOT NULL,
  `client_email` varchar(256) NOT NULL,
  `fk_prod` int(11) NOT NULL,
  `pu_ht` int(11) NOT NULL
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Déchargement des données de la table `commande_web`
--

INSERT INTO `commande_web` (`pk_commande`, `ref`, `fk_client`, `client_email`, `fk_prod`, `pu_ht`) VALUES
(11, 'CO-001', 1, 'email@client1.com', 1, 45),
(12, 'CO-002', 3, 'email@client2.com', 3, 150);

-- --------------------------------------------------------

--
-- Structure de la table `correspondance`
--

DROP TABLE IF EXISTS `correspondance`;
CREATE TABLE IF NOT EXISTS `correspondance` (
  `ID_client_ERP` int(11) NOT NULL,
  `ID_client_WEB` int(11) NOT NULL
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Déchargement des données de la table `correspondance`
--

INSERT INTO `correspondance` (`ID_client_ERP`, `ID_client_WEB`) VALUES
(1, 2),
(3, 12),
(2, 12),
(4, 16);

-- --------------------------------------------------------

--
-- Structure de la table `devis`
--

DROP TABLE IF EXISTS `devis`;
CREATE TABLE IF NOT EXISTS `devis` (
  `pk_devis` int(11) NOT NULL AUTO_INCREMENT,
  `ref` varchar(255) NOT NULL,
  `fk_client` int(11) NOT NULL,
  `date` date NOT NULL,
  PRIMARY KEY (`pk_devis`),
  KEY `fk_client` (`fk_client`)
) ENGINE=InnoDB AUTO_INCREMENT=4 DEFAULT CHARSET=utf8;

--
-- Déchargement des données de la table `devis`
--

INSERT INTO `devis` (`pk_devis`, `ref`, `fk_client`, `date`) VALUES
(1, 'DEV-001', 1, '2021-03-20'),
(2, 'DEV-002', 2, '2021-04-20'),
(3, 'DEV-003', 1, '2021-05-10');

-- --------------------------------------------------------

--
-- Structure de la table `ligne_des_devis`
--

DROP TABLE IF EXISTS `ligne_des_devis`;
CREATE TABLE IF NOT EXISTS `ligne_des_devis` (
  `pk_ligne` int(11) NOT NULL,
  `fk_devis` int(11) NOT NULL,
  `fk_produit` int(11) NOT NULL,
  `qty` int(11) NOT NULL,
  PRIMARY KEY (`pk_ligne`),
  KEY `fk_devis` (`fk_devis`),
  KEY `fk_prod` (`fk_produit`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Déchargement des données de la table `ligne_des_devis`
--

INSERT INTO `ligne_des_devis` (`pk_ligne`, `fk_devis`, `fk_produit`, `qty`) VALUES
(1, 1, 3, 1),
(2, 2, 2, 3),
(3, 2, 3, 2),
(5, 3, 2, 5);

-- --------------------------------------------------------

--
-- Structure de la table `produit`
--

DROP TABLE IF EXISTS `produit`;
CREATE TABLE IF NOT EXISTS `produit` (
  `pk_produit` int(11) NOT NULL,
  `ref` varchar(11) CHARACTER SET latin1 NOT NULL,
  `libelle` varchar(11) CHARACTER SET latin1 NOT NULL,
  `fk_cat` int(11) NOT NULL,
  `pu_ht` int(11) NOT NULL,
  PRIMARY KEY (`pk_produit`),
  KEY `fk_cat` (`fk_cat`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Déchargement des données de la table `produit`
--

INSERT INTO `produit` (`pk_produit`, `ref`, `libelle`, `fk_cat`, `pu_ht`) VALUES
(1, 'PDT_A', 'PRODUIT_A', 1, 150),
(2, 'PDT_B', 'PRODUIT_B', 2, 90),
(3, 'PDT_C', 'PRODUIT_C', 2, 45),
(4, 'PDT_D', 'PRODUIT_D', 0, 250),
(5, 'PDT_E', 'PRODUIT_E', 1, 30);

-- --------------------------------------------------------

--
-- Doublure de structure pour la vue `vue_devis_detail2`
-- (Voir ci-dessous la vue réelle)
--
DROP VIEW IF EXISTS `vue_devis_detail2`;
CREATE TABLE IF NOT EXISTS `vue_devis_detail2` (
`ID ligne` int(11)
,`ID devis (ligne)` int(11)
,`ID produit (ligne)` int(11)
,`quantité` int(11)
,`ID devis` int(11)
,`réf. devis` varchar(255)
,`client (devis)` int(11)
,`ID client` int(11)
,`Client` varchar(255)
,`Département` int(3)
,`e-mail` varchar(256)
,`Latitude` double(24,8)
,`Longitude` double(24,8)
,`ID produit` int(11)
,`libellé` varchar(11)
,`Catégorie produit` int(11)
,`ID cat.` int(11)
,`Prix Unit. HT` int(11)
,`libellé cat.` varchar(255)
);

-- --------------------------------------------------------

--
-- Structure de la vue `vue_devis_detail2`
--
DROP TABLE IF EXISTS `vue_devis_detail`;

DROP VIEW IF EXISTS `vue_devis_detail`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `vue_devis_detail2`  AS  select `ld`.`pk_ligne` AS `ID ligne`,`ld`.`fk_devis` AS `ID devis (ligne)`,`ld`.`fk_produit` AS `ID produit (ligne)`,`ld`.`qty` AS `quantité`,`d`.`pk_devis` AS `ID devis`,`d`.`ref` AS `réf. devis`,`d`.`fk_client` AS `client (devis)`,`c`.`pk_client` AS `ID client`,`c`.`nom` AS `Client`,`c`.`dept` AS `Département`,`c`.`email` AS `e-mail`,`c`.`latitude` AS `Latitude`,`c`.`longitude` AS `Longitude`,`p`.`pk_produit` AS `ID produit`,`p`.`libelle` AS `libellé`,`p`.`fk_cat` AS `Catégorie produit`,`cat`.`pk_cat` AS `ID cat.`,`p`.`pu_ht` AS `Prix Unit. HT`,`cat`.`libelle` AS `libellé cat.` from ((((`ligne_des_devis` `ld` left join `devis` `d` on((`ld`.`fk_devis` = `d`.`pk_devis`))) left join `client` `c` on((`c`.`pk_client` = `d`.`fk_client`))) left join `produit` `p` on((`ld`.`fk_produit` = `p`.`pk_produit`))) left join `categorie` `cat` on((`cat`.`pk_cat` = `p`.`fk_cat`))) ;

--
-- Contraintes pour les tables déchargées
--

--
-- Contraintes pour la table `devis`
--
ALTER TABLE `devis`
  ADD CONSTRAINT `devis_ibfk_1` FOREIGN KEY (`fk_client`) REFERENCES `client` (`pk_client`);

--
-- Contraintes pour la table `ligne_des_devis`
--
ALTER TABLE `ligne_des_devis`
  ADD CONSTRAINT `ligne_des_devis_ibfk_1` FOREIGN KEY (`fk_devis`) REFERENCES `devis` (`pk_devis`),
  ADD CONSTRAINT `ligne_des_devis_ibfk_2` FOREIGN KEY (`fk_produit`) REFERENCES `produit` (`pk_produit`);
COMMIT;